This website requires JavaScript.
Explore
Help
Sign In
pengyuthon
/
odoo_source
Watch
1
Star
0
Fork
0
Code
Issues
Pull Requests
Actions
Packages
Projects
Releases
Wiki
Activity
Files
30d315dfd95bccc1fb91c2fea9d7a31cf86ab6bf
odoo_source
/
addons
/
base
/
static
T
History
Fabien Meghazi
c57a3e0d98
[FIX] Fixed active_is in context for dialog actions
...
bzr revid:
fme@openerp.com-20110621143804-b51tp8n0a393oixi
2011-06-21 16:38:04 +02:00
..
lib
[IMP] converting values to strings with (new String) is 10~20% slower than using just String(). Switch Qweb.html_escape to String()
2011-06-21 11:18:36 +02:00
src
[FIX] Fixed active_is in context for dialog actions
2011-06-21 16:38:04 +02:00
test
[IMP] a bunch of improvements to groups handling in list view
2011-05-24 16:00:55 +02:00